import Taro from '@tarojs/taro';
import {View, Input, Image, ScrollView, Block} from '@tarojs/components';
import {connect} from '@tarojs/redux';
import {setUserInfo} from '@/actions/user';
import BaseComponent from '@/helper/baseComponent';
import {throttle} from '@/util/base';
import cityList from './city'
import NavBar from '@/components/NavBar'
// const citySimple = cityList.map(item => {
//   return {name: item.name, letter: item.letter};
// })

import './index.scss';

const letterMap = {};
const letterList = [];
cityList.forEach(city => {
  if (!letterMap[city.letter]) {
    letterMap[city.letter] = true;
    letterList.push(city.letter);
  }
})


@connect(({ user }) => ({
  user
}), (dispatch) => ({
  setUserInfo (data) {
    dispatch(setUserInfo(data || {}))
  }
}))
class CitySelect extends BaseComponent {

  config = {
    backgroundTextStyle: 'light',
    navigationBarBackgroundColor: '#FFFFFF',
    navigationBarTitleText: '城市选择',
    navigationBarTextStyle: 'black',
    pullRefresh: false
  }

  state = {
    cityList: cityList,
    letterList: letterList,
    curLetter: '',
    showSearch: false,
    keyword: '',
    searchList: [],
    page: 1
  }

  constructor(props) {
    super(props);
    this.search = throttle(this.search, 500).bind(this);
  }

  scrollToLetter = (letter) => {
    this.setState({
      curLetter: `city_${letter}`
    })
  }

  //文本框获取焦点
  handleFocus = () => {
    this.setState({
      showSearch: true
    })
  }

  search = () => {

  }

  handleInput = (e) => {
    // console.log(e.target.value);
    let value = e.target.value;
    let searchList = [];
    if (value) {
      searchList = cityList.filter(city => city.name.indexOf(value) > -1);
    }
    this.setState({keyword: value, searchList});
  }

  //清空文本框
  clearInput = () => {
    this.setState({keyword: '', searchList: []})
  }

  //选择城市
  selectCity = (item) => {
    const user = this.props.user;
    this.props.setUserInfo({
      // prevLongitude: user.longitude,
      // prevLatitude: user.latitude,
      longitude: item.longitude,
      latitude: item.latitude,
      city: item.name
    });
    // my.navigateBack();
    Taro.navigateBack();
    // eventCenter.trigger('selectCity', item);
  }

  //取消搜索
  cancelSearch = () => {
    this.setState({showSearch: false})
  }

  handleLoadMore = () => {
    // let page = this.state.page + 1;
    // let arr = cityList.slice((page - 1) * pageSize, page * pageSize);

    // let obj = arr.reduce((result, item, index) => {
    //   result[`cityList[${(page - 1) * pageSize + index}]`] = item;
    //   return result;
    // }, {});

    // console.log('obj....', obj, this);
    // obj.page = page;
    // this.state.page = page;
    // this.state.cityList.push(...arr);
    // this.$scope.setData(obj);
  }

  reLocation = () => {
    const user = this.props.user;
    let currentLoc = user && user.current;
    if (currentLoc && currentLoc.city && currentLoc.latitude && currentLoc.longitude) {
      this.selectCity({
        name: currentLoc.city,
        longitude: currentLoc.longitude,
        latitude: currentLoc.latitude
      })
    } else {
      this.fetchLocation();
    }
  }

  render() {
    const {
      cityList,
      letterList,
      curLetter,
      showSearch,
      keyword,
      searchList
    } = this.state;

    const user = this.props.user;
    let scrollStyle = ``


    return (
      <View>
      <NavBar pageName='我是标题' bgColor='#fff' showBack></NavBar>
        <View className={`header${showSearch ? ' searching': ''}`}>
          <View className='search'>
            <View className='input-wrapper'>
              <Image className='search-icon' src='http://hh-oss-picture.miyapay.com/box/9e4db125e6a4908a305904fbe531ba6b.png' />
              <Input value={keyword} onInput={this.handleInput} placeholder='请输入城市名称进行搜索' onFocus={this.handleFocus} />
              { showSearch && keyword && <Image onClick={this.clearInput} className='clear-icon' src='http://hh-oss-picture.miyapay.com/box/eeb1d09d119af463e73fd768f6ef656b.png' />}
            </View>
            { showSearch && <View className='cancel' onClick={this.cancelSearch}>取消</View> }
          </View>
          { !showSearch && <View className='current-city'>
            <Text className='cur-city-label'>当前城市定位</Text>
            <View className='city-name-wrapper' onClick={this.reLocation}>
              <Image className='loc-icon' src='http://hh-oss-picture.miyapay.com/box/45648a57e4c6d309cb438757a2029ba5.png' />
              <Text className='city-name' className=''>{user.current && user.current.city || '未获取定位'}</Text>
            </View>
          </View>}
        </View>
        <Block>
          <scroll-view onScrollToLower={this.handleLoadMore} style={`height: ${showSearch ? 0: '1200px'}`} scrollY className='city-list' scrollIntoView={curLetter}>
            {cityList.map((item, index) => {
              return (
                <Block className='city-item' key={index}>
                  { (index == 0 || cityList[index - 1] && item.letter !== cityList[index - 1].letter) && <View className='section' id={`city_${item.letter}`}>{item.letter}</View>}
                  <View
                    className={`city-name${cityList[index + 1] && cityList[index + 1].letter !== item.letter ? ' no-border' : ''}`}
                    onClick={this.selectCity.bind(this, item)}
                  >{item.name}</View>
                </Block>
              )
            })}
          </scroll-view>
          { !showSearch && <View className='letter-list'>
            {letterList.map((item, index) => {
              return <View key={index} className='letter' onClick={this.scrollToLetter.bind(this, item)}>{item}</View>
            })}
          </View>}
        </Block>
        <ScrollView style={{height: showSearch ? '100%':0}} scrollY className='search-list'>
          {searchList.map((item, index) => {
            return <View onClick={this.selectCity.bind(this, item)} key={index} className='city-name'>{item.name}</View>
          })}
        </ScrollView>
      </View>
    )
  }
}
export default CitySelect