import Taro, {Component} from '@tarojs/taro'
import { View, Image, Text, WebView} from '@tarojs/components'
import { connect } from '@tarojs/redux'
import { setUserOpenId } from '@/actions/user'
import {versionCompare} from '@/lib/util'
import './index.scss'

@connect(({ user }) => ({
  user
}), (dispatch) => ({
  setUserInfo (data) {
    dispatch(setUserOpenId(data || {}))
  },
}))
class Index extends Component {

  state = {
    payOpenIdExist: false, //支付公众号openid
    platform: Taro.getEnv(),
    startupPic: '',
    webview: '',
    SDKVersion: '',
  }
  componentWillReceiveProps (nextProps) {
    console.log(this.props, nextProps)
  }

  componentWillUnmount () { }
  componentDidMount() {
    //设置页面地址开始加载H5页面
    this.setState({
      webview: this.genWxAuthH5({
        platform: 'weixin',
        merchant: '123',
        app_id: 'wx16f1c332c4f9bd01',
        logo: encodeURIComponent('https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg'||'')
      })
    }, () => {
      console.log('我是h5的链接', this.state)
    })
    setTimeout(()=>{
      Taro.navigateTo({
        url: '/pages/index/index'
      })
    }, 2000)
  }
  componentDidShow () { }

  componentDidHide () { }
  // 查看支持的版本
  supportedWxSdk = () => {
    const res = Taro.getSystemInfoSync()
    this.setState({
      SDKVersion: res.SDKVersion
    })
		return versionCompare(res.SDKVersion, '2.1.0')
  }
  /**
   * 网页加载失败
   * @param {Object}
   */
  webViewError = (e) => {
    console.log('h5加载失败')
  }
  webViewSucess = (e) => {
    console.log('h5加载成功', e)
  }
  /**需要
   * 接收微信H5静默授权的网页发送的消息
   * 注：执行到该方法时，H5静默授权页面已经开始跳转页面了（H5完成的业务逻辑：1.静默授权，2.不通过首页过渡的页面直接跳转到该页面）
   */
  wxWebMessage (e) {
    console.log('h5加载成功.........', e)
    let {data=[]} = e.detail
    if(typeof data.slice !== 'function'){
      data = [data]
    }
    let page = decodeURIComponent(this.launch.page)
    //处理H5中不能处理的逻辑：通过首页过渡打开目标页面【打开方式， 1：到首页过渡， 2： 不通过首页过渡（专属活动使用较多）】
    setTimeout(()=>{
      Taro.navigateTo({
        url: '/pages/index/index'
      })
    }, 2000)

    data.forEach(item=>{
      if(item.type === 'auth'){
        this.props.setUserInfo({
          payOpenId: item.data.openId,
          clientId: Config.clientId
        })
      }
    })
  }
  /**需要
   * 生成微信H5授权地址
   */
  genWxAuthH5(params={}){
    let href = 'https://hh-oss-html.miyapay.com/saas/prod/wx_pay_auth/index.html', h5Params = []
    for(let key in params){
      h5Params.push(`${key}=${params[key]}`)
    }
    if(h5Params.length>0){
      href = `${href}?${h5Params.join('&')}`
    }

    //https://openauth.alipay.com/oauth2/publicAppAuthorize.htm?app_id=APPID&scope=SCOPE&redirect_uri=ENCODED_URL
    let options = [
      `appid=wx273772ce26499402`,
      `redirect_uri=${encodeURIComponent(href)}`,
      `response_type=code`,
      `scope=snsapi_base`
    ]
    // window.location.replace(`https://open.weixin.qq.com/connect/oauth2/authorize?${params.join('&')}`);
    return `https://open.weixin.qq.com/connect/oauth2/authorize?${options.join('&')}#wechat_redirect`
  }
  render () {
    const { webview, SDKVersion} = this.state
    return (
      <View className='page'>
        <View>
          {this.supportedWxSdk() && 
            <View>
              <Text>{webview}</Text>
              <WebView
                className='webview'
                src={webview}
                onError={this.webViewError}
                onLoad={this.webViewSucess}
                onMessage={this.wxWebMessage}
              >
              </WebView>
            </View>
          }
          {
            !this.supportedWxSdk() && 
            <View>
              <Text>当前客户端较低【{SDKVersion || '--'}】，请升级至最新版本 ~</Text>
            </View>
          }
        </View>
        <View class='wrapper'>
          <View>
            <View class='shopView animated fadeInDown'>
              <Image mode='widthFix' class='shopImage' style='width:300rpx;height:300rpx' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg'></Image>
            </View>
          </View>
        </View>
      </View>
    )
  }
}

export default Index
