import Taro from '@tarojs/taro'
import BaseComponent from '@/helper/baseComponent';
import { View, Image, Text, Swiper, SwiperItem, ScrollView, Button } from '@tarojs/components'
import { connect } from '@tarojs/redux'
import { setUserInfo } from '@/actions/user'
import NavBar from '@/components/NavBar'
import './index.scss'


@connect(({ user, nav }) => ({
  user, nav
}), (dispatch) => ({
  setUserInfo (data) {
    dispatch(setUserInfo(data || {}))
  },
}))
class Index extends BaseComponent {

  state = {
    located: false
  }
  componentWillReceiveProps (nextProps) {
    console.log(this.props, nextProps)
  }

  componentWillUnmount () { }
  componentDidMount() {
    this.handleLocation();
  }
  componentDidShow () { }

  componentDidHide () { }

  // 获取地址权限
  handleLocation() {
    this.fetchLocation().then(res => {
      this.setState({located: true})
    }).catch(err => {
      this.setState({located: true})
    })
  }
  // 手动选择地址
  selectCity(){
    Taro.navigateTo({
      url: '/pages/citySelect/index'
    })
  }
  // 跳转到门店详情
  jumpDetail = () => {
    Taro.navigateTo({
      url: '/pages/storeDetail/index'
    })
  }
  // 获取用户信息
  bindGetUserInfo = e => {
    console.log(e)
  }
  // 获取手机号
  bindGetPhoneNumber = e => {
    console.log(e)
  }
  render () {
    const {nav} = this.props
    const titleTop = (nav.globalData.navHeight - nav.globalData.navTop - 17) / 2 + nav.globalData.navTop
    const user = this.props.user;
    console.log('user', user)
    const noLoc = (!user || !user.longitude || !user.latitude);
    return (
      <View>
        <NavBar pageName='首页' bgColor='#fff'>
          <View
            style={`left:${nav.globalData.navRight}px;top:${titleTop}px;background-color:rgba(255,255,255,.6)`}
            className='city'
            onClick={this.selectCity}
          >
            <Image className='loc-icon' src='http://hh-oss-picture.miyapay.com/box/8dcd356a4ae1ff0c2c0ac9fd69733ab8.png' />
            <Text className={`${noLoc ? 'no-loc' : ''}`}>{noLoc ? '未获取定位' : user.city}</Text>
          </View>
        </NavBar>
        <Button openType='getUserInfo' onGetUserInfo={this.bindGetUserInfo}>授权登录</Button>
        <Button openType='getPhoneNumber' onGetPhoneNumber={this.bindGetPhoneNumber}>授权手机号</Button>
        <Swiper
          className='swpier-view'
          indicatorColor='#999'
          indicatorActiveColor='#333'
          circular
          indicatorDots
          autoplay
        >
          <SwiperItem>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
          </SwiperItem>
          <SwiperItem>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
          </SwiperItem>
          <SwiperItem>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
          </SwiperItem>
        </Swiper>
        <View className='sub-nav'>
          <View className='content'>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
            <Text>领券</Text>
          </View>
          <View className='content'>
            <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
            <Text>券包</Text>
          </View>
        </View>
        <View className='sub-title'>
          <Text>领券中心</Text>
          <Text>查看全部</Text>
        </View>
        <View className='store-list-title'>
          <Text>附近门店</Text>
        </View>
        <View>
          <ScrollView
            className='scrollview'
            scrollY
          >
            <View className='list-view' onClick={this.jumpDetail}>
              <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
              <View className='text-cont'>
                <Text>米雅遍历（北京店）</Text>
                <Text>营业时间 10:00 - 18:00</Text>
              </View>
              <View className='distance'>
                <Text>200m</Text>
              </View>
            </View>
            <View className='list-view'>
              <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
              <View className='text-cont'>
                <Text>米雅遍历（北京店）</Text>
                <Text>营业时间 10:00 - 18:00</Text>
              </View>
              <View className='distance'>
                <Text>200m</Text>
              </View>
            </View>
            <View className='list-view'>
              <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
              <View className='text-cont'>
                <Text>米雅遍历（北京店）</Text>
                <Text>营业时间 10:00 - 18:00</Text>
              </View>
              <View className='distance'>
                <Text>200m</Text>
              </View>
            </View>
            <View className='list-view'>
              <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
              <View className='text-cont'>
                <Text>米雅遍历（北京店）</Text>
                <Text>营业时间 10:00 - 18:00</Text>
              </View>
              <View className='distance'>
                <Text>200m</Text>
              </View>
            </View>
            <View className='list-view'>
              <Image className='img' src='https://ss0.bdstatic.com/94oJfD_bAAcT8t7mm9GUKT-xh_/timg?image&quality=100&size=b4000_4000&sec=1586229157&di=6997346b65b0e2e2ff7a733ae9b5fcc5&src=http://a3.att.hudong.com/14/75/01300000164186121366756803686.jpg' />
              <View className='text-cont'>
                <Text>米雅遍历（北京店）</Text>
                <Text>营业时间 10:00 - 18:00</Text>
              </View>
              <View className='distance'>
                <Text>200m</Text>
              </View>
            </View>
          </ScrollView>
        </View>
      </View>
    )
  }
}

export default Index
