
/**
 * 节流函数
 * @param {*} func
 * @param {*} wait
 * @param {*} options
 */
export function throttle(func, wait, options) {
  var context, args, result;
  var timeout = null;
  var previous = 0;
  if (!options) options = {};
  var later = function() {
    previous = options.leading === false ? 0 : Date.now();
    timeout = null;
    result = func.apply(context, args);
    if (!timeout) context = args = null;
  };
  return function() {
    var now = Date.now();
    if (!previous && options.leading === false) previous = now;
    var remaining = wait - (now - previous);
    context = this;
    args = arguments;
    if (remaining <= 0 || remaining > wait) {
      if (timeout) {
        clearTimeout(timeout);
        timeout = null;
      }
      previous = now;
      result = func.apply(context, args);
      if (!timeout) context = args = null;
    } else if (!timeout && options.trailing !== false) {
      timeout = setTimeout(later, remaining);
    }
    return result;
  };
};

//格式化距离
export const formatDistance = (distance) => {
  if (!distance) return '';
  if (distance < 1000) {
    return `${distance}m`;
  }
  return `${(distance / 1000).toFixed(1)}km`;
}


export const formatTime = (timestamp, fmt = 'yyyy-MM-dd hh:mm:ss', ms = true) => {
  const date = new Date()
  let fmtResult = fmt
  date.setTime(ms ? timestamp : timestamp * 1000)

  const o = {
    'M+': date.getMonth() + 1,
    'd+': date.getDate(),
    'h+': date.getHours(),
    'm+': date.getMinutes(),
    's+': date.getSeconds(),
    'q+': Math.floor((date.getMonth() + 3) / 3),
    S: date.getMilliseconds(),
  }

  if (/(y+)/.test(fmt)) {
    fmtResult = fmt.replace(RegExp.$1, `${date.getFullYear()}`.substr(4 - RegExp.$1.length))
  }

  Object.keys(o).forEach(k => {
    if (new RegExp(`(${k})`).test(fmtResult)) {
      fmtResult = fmtResult.replace(
        RegExp.$1,
        RegExp.$1.length === 1 ? o[k] : `00${o[k]}`.substr(`${o[k]}`.length),
      )
    }
  })

  return fmtResult
}

export const formatPathQuery = (path) => {
  let params = {}
  if(!path){
    return params;
  }
  try{
    let querys = path.replace(/[^\?]*\?|#.*$/g, '').split('&')
    for(let query of querys){
      let keys = query.split('=')
      params[keys[0]] = keys[1]
    }
    return params;
  }
  catch (e) {
    return params;
  }
}

export const formatMoney = (money) => {
  try {
   return (+money / 100);
  } catch(err) {
    console.log('errr', err);
    return ''
  }
}
